AtarimaniaAtarimania

Atari ST - 1992

GSZRZ

GSZRZ — screenshot 1
Genre
Communications / Radio / Electronics
Year
1992
Language
[unknown]
Publisher
[no publisher]
Controls
Keyboard / Mouse
Distributor
Resolution
Medium / High / VGA
Developer
Xenia Software
ST Type
ST, STe, TT, Falcon030 / 0.5MB
Licensed from
Programmer(s)
Ziegler, Michael
Country
Germany
MIDI
Software
German
Version
2.27
Box/Instructions
German
Number of Disks
1 / Double Sided
License
PD / Freeware / Shareware
Dump
Download
Serial
Dump format
MSA
Protection

INSTRUCTIONS

                                                    XENIA Software
                                                    Michael Ziegler
                                                    Jagdfeldring 16
                                                    8013 Haar
                                                    Tel. 089-4602746




                    GSZRZ Zmodem Paket für ATARI ST/TT





HAFTUNGSAUSSCHLUSS
------------------

Die Programme  wurden ausführlich getestet.  Für etwaige  Schäden, die
durch die Verwendung von Programmen  des GSZRZ Paketes entstehen, kann
ich keine Haftung übernehmen.

Sollten Sie  trotzdem einen Fehler feststellen  oder Verbesserungsvor-
schläge haben, so können sie mich  entweder unter der oben angegebenen
Anschrift oder über folgende Mailbox-Netze erreichen:

Michael Ziegler @ M im Mausnet
Michael Ziegler 2:246/70.5 im Fidonet



ÜBERBLICK
---------

    Das GSZRZ-Paket beinhaltet  die X/Y/ZMODEM Übertragungs-Protokolle
    für den ATARI ST/TT.

    Die  Programme sind  in Verbindung  mit  annähernd jedem  Terminal
    Programm einsetzbar.

    Der  Übertragungsstatus wird  in einer  Dialog-Box angezeigt.  Die
    letzte Meldung  bei Verlassen  wird auch  nach STDERR  ausgegeben.
    Wird GSZRZ mit RUFUS von Michael Bernards betrieben, so wird diese
    Message in das RUFUS-Terminalfenster ausgegeben.



DATEIEN
-------

    Folgende Dateien sind im GSZRZ Paket enthalten:

    GSZRZ_TT.ACC   ATARI TT Version das Accessory bzw. GEM Programmes
                   Diese Version ist NICHT auf dem ATARI ST lauffähig!
    GSZRZ_TT.TTP   ATARI TT Version OHNE GEM-Dialog-Box
                   Diese Version ist NICHT auf dem ATARI ST lauffähig!
    GSZRZACC.ACC   ATARI ST Version des Accessory bzw. GEM Programmes
    GSZRZ_ST.TTP   ATARI ST Version OHNE GEM-Dialog-Box
    GSZRZ.TXT      diese Dokumentation
    HISTORY.TXT    der Lebenslauf von GSZRZ
    GACCTEST.C     Pure-C Quellcode Beispiel für Accessory Schnitt-
                   stelle
    GACCTEST.TTP   Ausführbares Programm
    RS232ENC.LZH   Archiv des RTS/CTS Patches für den ATARI ST von
                   Michael Bernards
    SERPTCH2.LZH   Archiv des RTS/CTS Patches für den ATARI TT von
                   ATARI Computer

    Die Accessory  Programme können  auch durch  Umbennen als  normale
    GEM-Programme verwendet  werden. Durch  den ERSTEN  Parameter wird
    dann ausgewählt, ob  Senden (-sz) oder Empfang  (-rz) durchgeführt
    werden soll.


INSTALLATION
------------

    Die Installation hängt von dem verwendeten Terminalprogramm ab. An
    dieser Stelle ein paar Tips zur Installation mit RUFUS.

    Wenn  Sie genügend  Speicherplatz zur  Verfügung haben,  empfiehlt
    sich die Installation als Accessory.  Dann einfach GSZRZACC.ACC in
    das Rootdirectory kopieren. Im Dialog 'Protokoll' von RUFUS den 
    Slot ZMODEM einstellen. Dann Paramter sichern.

    Will man das TT-Accessory benützen,  so muß man es  entweder umbe-
    nennen,   oder  in   RUFUS.RUF   mit   einem  Editor   die   Zeile
    ACCNAME=GSZRZ_TT.ACC eintragen.


    Bei Verwendung  als PRG  (Accessory umbenennen  in PRG)  die Datei
    GSZRZxxx.PRG in das Modul-Directory von  RUFUS kopieren. Im Dialog
    'Protokoll'  von   RUFUS  einen  freien  Slot   einstellen.  Einen
    Protokoll-Namen  eintragen. Bei  Typ EXTERN  einstellen. Dann  bei
    Sender durch anklicken der Namenszeile GSZRZxxx.PRG auswählen. Bei
    Parameter  -sz und  eventuelle  andere  Paramter eintragen  (durch
    Leerzeichen  getrennt). Dann  bei  Empfänger  durch anklicken  der
    Namenszeile ebenfalls  GSZRZxxx.PRG auswählen.  Bei Parameter  -rz
    und  eventuelle   andere  Parameter  eintragen.   Dann  'Parameter
    sichern'.



COMMANDLINE PARAMETER
---------------------

    Bitte  achten Sie  darauf, daß  die Parameter  bei Gross-/  Klein-
    schreibung  unterschiedliche Bedeutung  aufweisen können!  Deshalb
    immer an die angegebenen Parameter  halten. Mehrere Parameter sind
    durch Leerzeichen getrennt anzugeben (siehe Beispiele).

    GSZRZ beinhaltet sowohl Sende- als auch Empfangsroutinen. Um GSZRZ
    mitzuteilen,  ob Senden  oder  Empfangen  erfolgen soll,  muß  als
    ERSTER Parameter  -sz für Senden  oder -rz für Empfangen angegeben
    werden. Bei Verwendung als Accessory  zusammen mit RUFUS wird dies
    automatisch durch RUFUS erledigt.

    Wird nicht  Parameter -a  angegeben, so  wird immer  im Binär-Mode
    übertragen!

    Von der  Übertragungsgeschwindigkeit her  gesehen, ist  das ZModem
    von GSZRZ  default auf die höchstmögliche  Übertragungsrate einge-
    stellt. Hat man  eine sehr schlechte Leitung und  kein MNP/V42, so
    ist es sicherer, wenn man mit Parameter -l 1024 eine Blockquittung
    verwendet  (siehe Parameter  -l  beim Senden).  Da  ist die  Über-
    tragung allerdings etwas langsamer.



PARAMETER bei EMPFANG
---------------------

Umsetzung von eingehenden Newline-Zeichen

    -a          Diese Funktion wird verwendet,  um ASCII Übertragungen
                z.B. von einem Unix System  auf den ATARI vorzunehmen.
                Dabei werden  eingehende Linefeeds  in Carriage-Return
                Linefeed umgesetzt.


Puffergröße:

    -b  SIZE    Mit diesem  Parameter wird  die Größe  des verwendeten
                Puffers der  seriellen Schnittstelle  für den  Empfang
                eingestellt. SIZE ist  die Größe des Puffers  in Byte.
                Der  eingestellte  Defaultwert von  1024  Byte  dürfte
                ausreichend sein.

                SIZE:  default 1024  Byte, minimal  128 Byte,  maximal
                       16384 Byte


Einstellen des CRC bei XModem

    -c          Wird dieser  Parameter angegeben,  so wird  bei XMODEM
                anstelle der Prüfsumme  ein 16 Bit CRC verwendet. Dies 
                ist im Prinzip  auch sicherer. Jedoch kann nicht jedes 
                Xmodem Protokoll auch mit CRC arbeiten.


Unterdrückung der Carrier-Überwachung

    -D          Wird  dieser Parameter  angegeben, so  wird die  Über-
                wachung des Carrier Detect unterdrückt.


Setzen des Datei Puffers

    -F SIZE     Mit diesem Parameter kann  die Grösse des Dateipuffers
                gesetzt  werden. Wenn  eine Datei  empfangen wird,  so
                werden die eingehenden Bytes in einem Puffer abgelegt.
                Ist dieser Puffer voll, so wird  er auf die Harddisk /
                Diskette  geschrieben.  Das beeinflußt  natürlich  die
                Übertragungsgeschwindigkeit. Darum kann  die Größe des
                Puffers  manipuliert werden.  Der  Parameter gibt  die
                Größe des Puffers in Byte an.

                SIZE: default  8192 Byte, minimal 1024  Bytes, maximal
                      262144 Bytes.


Einstellen des Stream-Modus bei XMODEM/YMODEM

    -g          Wird dieser  Parameter angegeben,  so wird  bei XMODEM
                bzw. YMODEM der Stream-Mode benützt. Das bedeutet, daß
                keine Quittung pro Datenblock  an den Sender geschickt
                wird.  Normalerweise   wird  nach   jedem  empfangenen
                Datenblock eine  Quittung an den Sender  geschickt, um
                mitzuteilen, daß  der Block  empfangen wurde.  Hat man
                eine zuverlässige Verbindung, (MNP5,  V42bis), so kann
                die  Übertragungsgeschwindigkeit durch Wegfall  dieser
                Quittung erhöht werden.


Akustische Anzeige des Übertragungsendes

    -G          Am Ende  der Übertragung wird  ein 'Pling'  ausgegeben


Übertragung über die MIDI Schnittstelle

    -m          Wird  dieser  Parameter  angegeben,   so  erfolgt  die
                Übertragung  nicht über  die RS232,  sondern über  die
                MIDI Schnittstelle. Dieser Parameter muß nicht angege-
                ben werden,  wenn GSZRZ  als Accessory  mit RUFUS  zu-
                sammen arbeitet. Da wird  automatisch immer die momen-
                tan bei RUFUS eingestellte Schnittstelle verwendet.
                (siehe Beispiel)

Abschalten des Maus-Interrupts

    -M          Durch diesen Parameter wird  der Mausinterrupt während
                der Übertragung abgeschaltet. Da bei manchen Benutzern
                Störungen der Übertragung auftraten,  wenn während der
                Übertragung die Maus bewegt wurde, ist es durch diesen
                Parameter möglich, den Mausinterrupt abzuschalten.


Verhalten bei bereits existierender Datei

    Bei YMODEM und ZMODEM wird der  Dateiname bereits durch den Sender
    vorgegeben.  Wenn dieser  Dateiname  bereits  existiert, kann  die
    Reaktion auf diesen Fall eingestellt werden.

    -e          Wenn die zu empfangende  Datei bereits existiert, wird
                der Dateityp auf  001, wenn dies auch  schon existiert
                auf 002 etc. umbenannt.


    -o FILE.EXT Der durch den Sender vorgegebene Dateinamen wird durch
                FILE.EXT ersetzt. Achtung: hier darf KEIN Pfad angeben
                werden.

    -p          Wenn Datei bereits existiert, durch SKIP an den Sender
                die  Übertragung dieser  Datei überspringen  (Achtung:
                kleines 'p' verwenden!)

    -y          Wenn  die Datei  bereits  existiert,  dann soll  diese
                gelöscht werden.


Festlegen des Download-Directories

    -P PFAD     Durch Angabe dieses Parameters kann  das Zieldirectory
                bestimmt   werden.   Wird   dieser   Parameter   nicht
                angegeben,  so  landen  empfangene  Dateien  immer  im
                aktuellen Directory.


Ausgaben bei Verlassen von GSZRZ an STDERR unterdrücken


    -q          Wird dieser  Parameter angegeben, so wird  die Ausgabe
                der letzten  Meldung an STDERR  unterdrückt. (Sinnvoll
                bei Terminalprogrammen, die keine Umlenkung von STDERR
                vornehmen)


Fortsetzen des Empfangs eines abgebrochenen Downloads

    -r          Wenn Datei bereits besteht, dann  mit Resume die Über-
                tragung fortsetzen. (nur bei ZMODEM)


Setzen des Systemdatums für eine empfangene Datei.

    -s          Das File-Datum für empfangene Dateien auf das aktuelle
                Datum   setzen.  (Y/ZMODEM)   Kann  hauptsächlich   in
                Mailboxprogrammen von Nutzen sein.


Ausgabe der erreichten CPS Rate am Ende der Übertragung

    -S          Wird dieser Parameter  angegeben, so wird am  Ende der
                Übertragung  die  erreichte CPS-Rate  an  STDERR  aus-
                gegeben.


Einstellen der Timeout Zeit

    -t TIM      Die  Timeout  Zeit  wird   auf  TIM  Zehntel  Sekunden
                gesetzt.  Wurde   aufgenommen,  da   scheinbar  manche
                Mailboxen  recht  lange  brauchen,   bis  eine  ZMODEM
                Übertragung aufgenommen wird.  Normalerweise sollte es
                mit der Default-Einstellung aber keine Probleme geben.
                Defaultwert: 100, min: 10, max 1000


Protokoll bei Empfang

    Default wird ZMODEM verwendet. Soll eines der anderen Protokolle 
    verwendet werden, so kann dies durch folgende Parameter erreicht 
    werden:

    -X          XMODEM-Protokoll verwenden

    -Y          YMODEM-Protokoll verwenden



Compression von ASCII Dateien

    -z          RLE Kompression verwenden. Ist nur dann sinnvoll, wenn
                im  ASCII-Mode  übertragen  wird und  KEIN  MNP5  oder
                V42bis eingesetzt wird. RLE  ist ein relativ einfacher
                Kompressionsalgorithmus. Dafür aber so schnell, daß es
                die Übertragungsrate immer noch positiv beeinflußt.


Überprüfung der Online Zeit

    -U time         verbleibende Onlinezeit
    -C baudrate     aktuelle Baudrate

    Für den  Einsatz in  Mailboxprogrammen wurde  für den  Empfang die
    Prüfung der noch verbleibenden  Online-Zeit aufgenommen (Stichwort
    NetCall Hour). Dazu sind die beiden Parameter -C und -U notwendig.
    Bei -C wird  der folgende Wert als  aktuelle Baudrate ausgewertet.
    -U ist die  restliche Onlinezeit in Sekunden. Reicht  die Zeit für
    einen Upload  nicht mehr aus,  so wird RZ  mit Exitcode 9  und dem
    Hinweis  'not  enough  time for  upload'  abgebrochen.  Zu  diesem
    Zeit-punkt ist  noch keine  Datei angelegt,  es bleiben  also auch
    keine  Datei-Leichen  zurück.  Wird  durch  Blockwiederholung  die
    verfügbare  Online-Zeit überschritten,  so  wird  der Empfang  mit
    Exitcode 10  abgebrochen. Die  empfangene Datei  wird geschlossen,
    kann also eventuell später komplettiert werden.

    Beispiel: -rz -C 19200 -U 100


BEISPIELE
---------

Ein paar Beispiele für Aufrufe von RZ:

-rz                  Empfang mit ZMODEM

-rz -Y               Empfang mit YMODEM

-rz -Y -g            Empfang mit YMODEM-1k-g

-rz -X TEST.XYZ      Empfang mit XMODEM. Bei Empfang mit XMODEM  M U S S
                     immer ein Dateiname angegeben werden, da bei XMODEM
                     der Dateiname nicht mit übertragen wird!

-rz -y -o TEST.XYZ -P D:\MAIL\DOWNLOAD
                     Empfang mit ZMODEM,  Carrierüberwachung disabled,
                     Zieldirectory   vorgeben,   Dateiname   vorgeben,
                     eventuell vorhandene Datei löschen.

rz -m                Empfang über die MIDI-Schnittstelle




PARAMETER bei SENDEN
--------------------

Mögliche Commandline-Parameter bei Senden:

Anhängen an existierende Datei

   -+           Der Empfänger soll an ein existierendes File anhängen.
                Nur ZModem.


ASCII Transfer

   -a           ASCII-Transfer, Rx soll CRLF übersetzen. Nur ZModem.


Break unterdrücken

   -b           Bei einem Retry wird KEIN Break an das Modem ausge-
                geben. Nur ZModem. Normal wird bei einer Blockwieder-
                holung ein Break an das Modem geschickt, um den 
                Modem-Puffer zu leeren.


Konvertieren von '.'

   -d           Punkte '.' in Pfadnamen in '/' konvertieren. Nur bei
                YModem und ZModem. Wenn der Empänger keine '.' in 
                Dateinamen haben will/kann.


Carrier Überwachung

   -D           Überwachung des Carrier Detect unterdrücken


Pfadangaben an Empfänger senden

   -f           Wird dieser Parameter angegeben, so wird die komplette
                Pfadangabe  mit  dem Dateinamen  übertragen.  Nur  bei
                ZModem.


Setzen des Datei Puffers

   -F SIZE      Mit diesem Parameter kann  die Grösse des Dateipuffers
                gesetzt  werden. Wenn  eine Datei  empfangen wird,  so
                werden die eingehenden Bytes in einem Puffer abgelegt.
                Ist dieser Puffer voll, so wird  er auf die Harddisk /
                Diskette  geschrieben.  Das beeinflußt  natürlich  die
                Übertragungs-geschwindigkeit. Darum kann die Größe des
                Puffers  manipuliert werden.  Der  Parameter gibt  die
                Größe des Puffers in Byte an.

                SIZE: default  8192 Byte, minimal 1024  Bytes, maximal
                      262144 Bytes.


Akustische Anzeige des Übertragungsendes

    -G          Am Ende der Übertragung wird ein 'Pling' ausgegeben


Blockgröße bei XModem / YModem

    -k          1024 Byte Pakete senden. Default werden bei XModem und
                YModem 128 Byte Pakete verwendet.


Empfänger Quittung anfordern

    -l N        Alle  N  Bytes  (32  <= N  <=  1024)  Quittierung  von
                Empfänger anfordern. Nur bei  ZModem. Default wird bei
                ZModem der Stream-Mode verwendet. Das bedeutet daß der
                Sender  fortlaufend  Datenblöcke schickt  und  nur  im
                Fehlerfall  vom Empfänger  zu einer  Blockwiederholung
                aufgefordert  wird. Dadurch  wird  im Stream-Mode  ein
                höherer  Datendurchsatz  erreicht. Ist aber kein Hard-
                ware-Handshake  vorhanden (z.B. MIDI) muß durch diesen
                Parameter für ein Software Handshake gesorgt werden.


Übertragung über die MIDI Schnittstelle

    -m          Wird  dieser  Parameter  angegeben,   so  erfolgt  die
                Übertragung  nicht über  die RS232,  sondern über  die
                MIDI   Schnittstelle.  Dieser   Parameter  muß   nicht
                angegeben werden,  wenn GSZRZ als Accessory  mit RUFUS
                zusammen  arbeitet.  Da  wird  automatisch  immer  die
                momentan   bei   RUFUS    eingestellte   Schnittstelle
                verwendet.

                Da  es bei  der  MIDI  Schnittstelle keine  Handshake-
                leitungen gibt, muß  man durch Angabe von  -l 1024 für
                ein Software-Handshake sorgen.


Abschalten des Maus-Interrupts

    -M          Durch diesen Parameter wird  der Mausinterrupt während
                der Übertragung abgeschaltet. Da bei manchen Benutzern
                Störungen der Übertragung auftraten,  wenn während der
                Übertragung die Maus bewegt wurde, ist es durch diesen
                Parameter möglich, den Mausinterrupt abzuschalten.


Bedingte Übertragung  
   
    -n          Datei nur dann senden, wenn sie NEUER oder länger ist,
                als eine bereits beim Empfänger existierende Datei. 
                Nur ZModem.


    -N          Datei nur  dann senden, wenn  sie länger ist  oder ein
                ANDERES  Datum  aufweist,  als   beim  Empfänger.  Nur
                ZModem.


16 Bit CRC

    -o          Bei ZMODEM nur  16 Bit CRC verwenden.  Spart pro über-
                tragenem  Block 2  Byte. Ist  also  was für  Geschwin-
                digkeitsfanatiker :-) Es gibt ältere ZModem Programme,
                die nur 16 Bit CRC verwenden.


Schützen einer bereits vorhandenen Datei

    -p          Wenn die zu übertragende  Datei bereits beim Empfänger
                existiert,  wird die  Übertragung NICHT  durchgeführt.
                Nur bei ZModen.


Ausgaben bei Verlassen von GSZRZ an STDERR unterdrücken


    -q          Wird dieser  PArameter angegeben, so wird  die Ausgabe
                der letzten  Meldung an STDERR  unterdrückt. (Sinnvoll
                bei Terminalprogrammen, die keine Umlenkung von STDERR
                vornehmen)


Fortsetzen einer abgebrochenen Übertragung

    -r          Wenn die  Datei beim  Empfänger bereits  besteht, dann
                soll die  Übertragung mit  Resume fortgesetzt  werden.
                Das bedeutet,  daß mit der  Übertragung an  der Stelle
                fortgefahren   wird,  wo   eine  frühere   Übertragung
                abgebrochen  wurde.  Das  sollte man  aber  nnur  dann
                machen, wenn man sich absolut  sicher ist, daß es sich
                um exact die gleiche Datei handelt.


Script File für Senden benützen

    -s FILE.EXT Die  Namen der  zu sendenden  Dateien  werden aus  dem
                Script-File Datei.Ext gelesen.  Nur ZModem. Praktisch,
                wenn man  wiederholt die  gleichen Dateien  übertragen
                muß.


Ausgabe der erreichten CPS Rate am Ende der Übertragung

    -S          Wird dieser Parameter  angegeben, so wird am  Ende der
                Übertragung  die  erreichte CPS-Rate  an  STDERR  aus-
                gegeben.


Einstellen der Timeout Zeit

    -t TIM      Die  Timeout  Zeit  wird   auf  TIM  Zehntel  Sekunden
                gesetzt. Das  ist die Zeit,  die auf eine  Antwort vom
                Empfänger  gewrtet  wird, bis  ein  Fehler  angenommen
                wird.    Normalerweise     sollte    es     mit    der
                Default-Einstellung   aber   keine   Probleme   geben.
                Defaultwert: 600, min: 10, max 1000


Datei löschen

    -u          Die zu übertragende Datei soll nach der Übertragung 
                gelöscht werden.


Existierende Datei überschreiben

    -y          Der Empfänger soll eine eventuell bereits existierende
                Datei gleichen Namens überschreiben. Nur ZModem.


Protokoll bei Senden

    Default wird ZMODEM verwendet. Soll eines der anderen Protokolle 
    verwendet werden, so kann dies durch folgende Parameter erreicht 
    werden:

    -X          XMODEM-Protokoll verwenden

    -Y          YMODEM-Protokoll verwenden


Compression von ASCII Dateien

    -z          RLE Kompression verwenden. Ist nur dann sinnvoll, wenn
                im  ASCII-Mode  übertragen  wird und  KEIN  MNP5  oder
                V42bis eingesetzt wird. RLE  ist ein relativ einfacher
                Kompressionsalgorithmus. Dafür aber so schnell, daß es
                die Übertragungsrate immer noch positiv beeinflußt.


Große Blöcke übertragen

    -8          Beim  Senden  8KB  Blöcke  verwenden.  ACHTUNG:  Diese
                Option verträgt sich nur mit wenigen ZModem Programmen
                am anderen Ende.



BEISPIELE
---------

Ein paar Beispiele für Parameterangaben beim Senden

sz TEST.XYZ             Senden mit ZMODEM

sz *.C *.H              Alle Dateien mit der Extension .C und .H mit
                        ZMODEM senden.

sz -Y TEST.XYZ          Senden mit YMODEM

sz -Y -k TEST.XYZ       Senden mit YMODEM-1k-g

sz -X TEST.XYZ          Senden mit XMODEM

sz -8 TEST.XYZ          Senden mit ZMODEM in 8 KB Blöcken

sz -m -l 1024 TEST.XYZ  Senden über die MIDI Schnittstelle.

Wird am anderen Ende auch GSZRZ verwendet, so kann durch Angabe von

sz -m -8 -l 8192 TEST.XYZ auch in 8 KB-Blöcken übertragen werden.



EXITCODES
---------

Folgende Exitcodes werden  von GSZRZ bei Beendigung  des Programmes an
den Aufrufer zurückgegeben:

1  Argument Fehler, Commandline  fehlerhaft
2  Initialisierungsfehler (graf_handle,  appl_init)
3  Abbruch durch Eingabe von Ctrl-Alt
4  Speicher Anforderungsfehler, nicht genug  Speicher vorhanden
5  Carrier lost
8  ungültiger Struktur Zeiger (siehe ACC-Protokoll)

128- Transfer-Fehler  Sollen z.B. 4 Files gesendet werden und bei 2
                      Dateien SKIPPED der Receiver, so wird 128 + 2
                      = 130 zurückgegeben. Kommt gar kein Sync zu-
                      stande (Timeout), wird 128 zurückgegeben.



ACC-PROTOKOLL von GSZRZ
-----------------------

GSZRZ als  ACC wird  durch ein  spezielles Protokoll  über die  Appli-
cation-Message Funktion des GEM angesprochen.

msgbuf[0]   enthält die Kenn-Nummer für das ACC Protokoll. Sie
            besteht aus den beiden Buchstaben 'GZ' entsprechend
            dem Hexwert 0x475A.

msgbuf[1]   enthält den Application-ID, also den Wert, der bei
            appl_init() als Rückgabewert erhalten wird.

msgbuf[2]   muß immer 0 sein

msgbuf[3]   enthält die Länge des Commandlinestrings.

msgbuf[4]   untere 16 Bit des Pointers auf den Commandline String.

msgbuf[5]   obere 16 Bit des Pointers auf den Commandline String.

            Der Commandline-String  muss mit 0x00  abgeschlossen sein.
            Er beinhaltet  die üblichen Switches,  wie bei  Aufruf als
            PRG, also z.B. "-rz -D -P C:\\DOWNLOAD"

msgbuf[6]   untere 16 Bit des unten beschriebenen Struktur-Pointers
msgbuf[7]   obere 16 Bit des Struktur Pointers


typedef struct
{
    int version;                        /* Versionsnummer */
    int baud;
    int flow;
    int ucr;
    int flags;
    int nbaud;
    unsigned *bauds;

    /* nun folgen die Pointer auf verschiedene Funktionen */

    void (*set_rs232)(int baud, int flow, int ucr);
    int (*instat)(void);                /* Rx Status        */
    int (*in)(void);                    /* Rx Character     */
    int (*outstat)(void);               /* Tx Status        */
    void (*out)(int c);                 /* Tx Character     */
    void (*send_break)(int brktim);     /* send break       */
    int (*carrier)(void);               /* Carrier Status   */
    void (*DTR)(int on_off);
    int (*DSR)(void);
}COM;

Von  dieser Struktur  werden von  GSZRZ nur  die Function-Pointer  für
Rx-Status,  Rx-Character,  Tx-Status,  Tx-Character,  Send  Break  und
Carrier-Status sowie 'version' verwendet.

In  'version'  ist  die   Versionsnummer  des  aufrufenden  Programmes
enthalten. Die höherwertigen 16 Bit entsprechen der Versionsnummer vor
dem  Komma. Die  niederwertigen  16 Bit  nach  dem Komma.  Ausgewertet
werden nur die oberen 16 Bit. Diese müssen den Wert 1 enthalten. Damit
ist gewährleistet, daß die Struktur den richtigen Aufbau enthält.

Kann kein gültiger Strukturpointer festgestellt  werden, so werden die
Bios-funktionen der aktuell eingestellten Schnittstelle benützt.



Rückmeldungen von GSZRZ 
=======================

Wenn GSZRZ beendet wird, so erfolgt eine Rückmeldung an des aufrufende
Programm:

msgbuf[0] = GZ_PRIVATE;
msgbuf[1] = appl_id;
msgbuf[2] = Exitcode;
msgbuf[3] = (int) strlen(Meldung);
msgbuf[4] = (unsigned int) ((long) Meldung & 0XFFFF);
msgbuf[5] = (unsigned int) ((long) Meldung >> 16);
msgbuf[6] = 0;
msgbuf[7] = 0;
appl_write(msgbuf[1], 16, txmsgbuf);


Meldung ist ein Pointer auf den String, der normal von GSZRZ am Ende
an 'stdout' ausgegeben wird. Bei RUFUS landet dieser String als Meldung von 
GSZRZ imTerminalfenster.

Exitcode enthält den Returncode von GSZRZ.




RTS/CTS HANDSHAKE
-----------------

Da die Programme über die  Betriebssystem-Routinen des ST/TT arbeiten,
muss ein  eventuelles RTS/CTS-Handshake entweder  vom Terminalprogramm
(z.B. RUFUS) oder über das Kontrollfeld vorgenommen werden.

Da die TOS-Routinen leider  sogar in TOS 1.04 und TOS  3.05 noch immer
fehlerhaft sind, muss ein Patch installiert sein.

Für den ATARI ST kann ich RS232ENC empfehlen, das von Michael Bernards,
dem Autor des Terminalprogrammes RUFUS, stammt.

Für den  TT empfiehlt sich SERPTCH2 von  ATARI, da werden  gleich alle
Schnittstellen repariert.

Bei TOS 3.06 ist SERPTCH2 nicht mehr notwendig.



SHAREWAREVERSIONEN
------------------

Die Programme SZ.PRG und RZ.PRG in  GEM-Version sind nur bis Versionen
kleiner als 2.0  SHAREWARE. Das bedeutet für den Anwender,  daß er die
Programme der Versionen < 2.0 frei  kopieren und 3 Wochen testen kann.
Alle  Versionen  ab  2.0 und  aufwärts  sind  persönlich  registrierte
Versionen, die nicht weitergegeben werden dürfen.

Werden die Programme  der Versionen < 2.0 über  diesen Zeitraum hinaus
weiter benutzt,  so ist die  EINMALIGE Shareware-Gebühr von  DM 30.-an
den Autor zu entrichten. Der Betrag ist nur einmalig zu entrichten und
berechtigt auch zur Benutzung künftiger GSZRZ-Versionen.

Bei Überweisungen  aus dem AUSLAND bitte  daran denken, daß bis  zu DM
10.--an Gebühren anfallen können! (z.B. Schweiz DM 7.50)

Registrierte Benutzer bekommen gegen EINSENDUNG EINER LEERDISKETTE UND
EINEM FRANKIERTEN  RÜCKUMSCHLAG die Vollversion. Diese  beinhaltet die
Implementation von XMODEM, XMODEM-1k, XMODEM-g, YMODEM-g, YMODEM Batch
und ZMODEM.

Versionen  mit Versionsnummer  >=  2.0  werden NICHT  MEHR  öffentlich
verteilt, sondern nur noch an lizensierte Benutzer vergeben.



DANKESCHÖN
----------

An dieser Stelle möchte ich mich bei meinen Betatestern bedanken.

Mein Dank gilt vor allem:

Jürgen Meyer, Carsten Meyer Maus @HH2, für das aufopfernde Testen,

Michael Bernards für die Unterstützung durch RUFUS 1.11

allen Benutzern von GSZRZ, die durch immer neue Vorschläge für eine

Weiterentwicklung des GSZRZ Zmodem Paketes sorgen.




UPDATE-SERVICE
--------------

Für  registrierte  GSZRZ  Benutzer gibt  es  einen  Update-Service  in
verschiedenen Mailboxen.

Bis ein neu  registrierter Benutzer diesen Service  in Anspruch nehmen
kann, können ca. 1-2 Wochen vergehen, da die Datei mit den Registrier-
Daten in unregelmäßigen Abständen in  der jeweiligen Mailbox upgedatet
wird.

Dieser Service  ist eine kostenfreie  Einrichtung, die auf  Wunsch von
Mailbox   Betreibern  eingerichtet   wurde.  Ich   kann  daher   nicht
garantieren,  daß dieser  Service  jederzeit  erreichbar ist  und  die
aktuellste Version des GSZRZ Paketes installiert hat.

Für den Update ist die Seriennummer Ihres GSZRZ Paketes notwendig.
Diese steht in der Datei SERIAL.NUM auf der Original-Diskette.

Nach einloggen in die Mailbox muß  aus dem Menü der Updater aufgerufen
werden. Das  kann je  nach Mailbox  unterschiedlich erfolgen.  Ist der
Updater aufgerufen, so meldet er sich mit folgendem Text:


>> Registering GSZRZ-Files V 2.6 (c) 1991, 1992 mz <<

A C H T U N G:  Nur für REGISTRIERTE Benutzer erlaubt!
aktulle Version x.yy downloaden ? (J/N)

Vorname:
Nachname:
Seriennummer:

Nach Eingabe der  erforderlichen Daten wird eine  registrierte Version
erstellt, mit  LHARC gepackt und  anschliessend wahlweise  mit Y-Modem
oder Z-Modem gesendet.

Bitte achten Sie bei der Schreibweise von Vor-und Nachname darauf, daß
diese exakt  wie in  dem Dialogfenster  angezeigt, eingegeben  werden.
Anderenfalls werden Sie als nicht updateberechtigt zurückgewiesen.

Der Update-Service wird von folgenden Mailboxen angeboten:

------------------------------------------------------------------------
TURBO TRON HAMBURG

Tel.: 040-890 11 62

Bps: 1200-14400 V32BIS/V42BIS/HST

Onlinezeiten: 18:00  Uhr -2:00 Uhr 20  Minuten 2:00 Uhr -8:00  Uhr 120
Minuten 8:00 Uhr -18:00 Uhr 45 Minuten

-Gastdownload nicht  erlaubt !
-Allerdings kann der Updater auch als Gast aufgerufen werden, also ist
 ein Eintrag als User der Box nicht notwendig !
-Kurzwort oder Cursorsteuerung moeglich
-Updateraufruf durch GSZ im Menue.
------------------------------------------------------------------------
TUMA BOX AUGSBURG

Tel.: 0821-667766

Bps: 1200-14400 V32BIS/V42BIS

Onlinezeiten: 24h 

-Gastdownload erlaubt (1 Datei pro Anruf)
-Allerdings kann der Updater auch als Gast aufgerufen werden, also ist
 ein Eintrag als User der Box nicht notwendig !
-Kurzwort oder Cursorsteuerung moeglich
-Updateraufruf durch GSZ im Menue.
------------------------------------------------------------------------



ADRESSE
-------

XENIA Software                       XENIA Software
Michael Ziegler                      Michael Ziegler
Jagdfeldring 16                      Kreissparkasse München
D-8013 Haar                          BLZ 702 501 50
                                     Kto: 420354680

----------------------------------------------------------------------